==> mailpoet.4.48.1.zip: mailpoet/vendor-prefixed/symfony/dependency-injection/Exception/ParameterNotFoundException.php <==
<?php
namespace MailPoetVendor\Symfony\Component\DependencyInjection\Exception;
if (!defined('ABSPATH')) exit;
use MailPoetVendor\Psr\Container\NotFoundExceptionInterface;
class ParameterNotFoundException extends InvalidArgumentException implements NotFoundExceptionInterface
{
 private $key;
 private $sourceId;
 private $sourceKey;
 private $alternatives;
 private $nonNestedAlternative;
 public function __construct(string $key, string $sourceId = null, string $sourceKey = null, \Throwable $previous = null, array $alternatives = [], string $nonNestedAlternative = null)
 {
 $this->key = $key;
 $this->sourceId = $sourceId;
 $this->sourceKey = $sourceKey;
 $this->alternatives = $alternatives;
 $this->nonNestedAlternative = $nonNestedAlternative;
 parent::__construct('', 0, $previous);
 $this->updateRepr();
 }
 public function updateRepr()
 {
 if (null !== $this->sourceId) {
 $this->message = \sprintf('The service "%s" has a dependency on a non-existent parameter "%s".', $this->sourceId, $this->key);
 } elseif (null !== $this->sourceKey) {
 $this->message = \sprintf('The parameter "%s" has a dependency on a non-existent parameter "%s".', $this->sourceKey, $this->key);
 } else {
 $this->message = \sprintf('You have requested a non-existent parameter "%s".', $this->key);
 }
 if ($this->alternatives) {
 if (1 == \count($this->alternatives)) {
 $this->message .= ' Did you mean this: "';
 } else {
 $this->message .= ' Did you mean one of these: "';
 }
 $this->message .= \implode('", "', $this->alternatives) . '"?';
 } elseif (null !== $this->nonNestedAlternative) {
 $this->message .= ' You cannot access nested array items, do you want to inject "' . $this->nonNestedAlternative . '" instead?';
 }
 }
 public function getKey()
 {
 return $this->key;
 }
 public function getSourceId()
 {
 return $this->sourceId;
 }
 public function getSourceKey()
 {
 return $this->sourceKey;
 }
 public function setSourceId(?string $sourceId)
 {
 $this->sourceId = $sourceId;
 $this->updateRepr();
 }
 public function setSourceKey(?string $sourceKey)
 {
 $this->sourceKey = $sourceKey;
 $this->updateRepr();
 }
}

==> mailpoet.4.54.0.zip: mailpoet/vendor-prefixed/symfony/dependency-injection/Exception/ParameterNotFoundException.php <==
<?php
namespace MailPoetVendor\Symfony\Component\DependencyInjection\Exception;
if (!defined('ABSPATH')) exit;
use MailPoetVendor\Psr\Container\NotFoundExceptionInterface;
class ParameterNotFoundException extends InvalidArgumentException implements NotFoundExceptionInterface
{
 private $key;
 private $sourceId;
 private $sourceKey;
 private $alternatives;
 private $nonNestedAlternative;
 public function __construct(string $key, ?string $sourceId = null, ?string $sourceKey = null, ?\Throwable $previous = null, array $alternatives = [], ?string $nonNestedAlternative = null)
 {
 $this->key = $key;
 $this->sourceId = $sourceId;
 $this->sourceKey = $sourceKey;
 $this->alternatives = $alternatives;
 $this->nonNestedAlternative = $nonNestedAlternative;
 parent::__construct('', 0, $previous);
 $this->updateRepr();
 }
 public function updateRepr()
 {
 if (null !== $this->sourceId) {
 $this->message = \sprintf('The service "%s" has a dependency on a non-existent parameter "%s".', $this->sourceId, $this->key);
 } elseif (null !== $this->sourceKey) {
 $this->message = \sprintf('The parameter "%s" has a dependency on a non-existent parameter "%s".', $this->sourceKey, $this->key);
 } else {
 $this->message = \sprintf('You have requested a non-existent parameter "%s".', $this->key);
 }
 if ($this->alternatives) {
 if (1 == \count($this->alternatives)) {
 $this->message .= ' Did you mean this: "';
 } else {
 $this->message .= ' Did you mean one of these: "';
 }
 $this->message .= \implode('", "', $this->alternatives) . '"?';
 } elseif (null !== $this->nonNestedAlternative) {
 $this->message .= ' You cannot access nested array items, do you want to inject "' . $this->nonNestedAlternative . '" instead?';
 }
 }
 public function getKey()
 {
 return $this->key;
 }
 public function getSourceId()
 {
 return $this->sourceId;
 }
 public function getSourceKey()
 {
 return $this->sourceKey;
 }
 public function setSourceId(?string $sourceId)
 {
 $this->sourceId = $sourceId;
 $this->updateRepr();
 }
 public function setSourceKey(?string $sourceKey)
 {
 $this->sourceKey = $sourceKey;
 $this->updateRepr();
 }
}
